@@ -19,16 +19,16 @@
 \****************************************************************************/
 
 /*!
- * \file check_symbols.cc
+ * \file check-symbols.cc
  *
  * \brief Provides classes and functions in order to check the correct use of
  * 	  symbols within a BPEL process.
  *
  * \author  
- *          - last changes of: \$Author: gierds $
+ *          - last changes of: \$Author: nlohmann $
  *          
  * \date
- *          - last changed: \$Date: 2006/01/07 16:14:43 $
+ *          - last changed: \$Date: 2006/02/17 14:18:25 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universit&auml;t zu Berlin. See
@@ -61,6 +61,7 @@ SymbolManager::SymbolManager()
 /// destructor for class SymbolManager
 SymbolManager::~SymbolManager()
 {
+  trace(TRACE_DEBUG, "[CS] Destroying SymbolManager ...\n");
   // if != NULL we have scopes (should always be so)
   if (processScope != NULL)
   {
@@ -74,6 +75,7 @@ SymbolManager::~SymbolManager()
     processScope = NULL;
     currentScope = NULL;
   }
+  trace(TRACE_DEBUG, "[CS] Destroying SymbolManager done.\n");
 }  
 
 /**
@@ -582,7 +584,7 @@ kc::casestring SymbolManager::checkLink(csLink* link, bool asSource)
     if (asSource)
     {
       scope = currentScope;
-      if (scope != NULL and inBLM)
+      if (scope != NULL && inBLM)
       {
         scope = scope->parent;
       }
